"""Provide appliance models for the Home Connect API."""

from __future__ import annotations

from dataclasses import dataclass, field
from enum import StrEnum

from mashumaro import field_options
from mashumaro.mixins.json import DataClassJSONMixin


class ApplianceType(StrEnum):
    """Represent an appliance type."""

    AIR_CONDITIONER = "AirConditioner"
    CLEANING_ROBOT = "CleaningRobot"
    COFFEE_MAKER = "CoffeeMaker"
    COOK_PROCESSOR = "CookProcessor"
    COOKTOP = "Cooktop"
    DISHWASHER = "Dishwasher"
    DRYER = "Dryer"
    FREEZER = "Freezer"
    FRIDGE_FREEZER = "FridgeFreezer"
    HOOD = "Hood"
    MICROWAVE = "Microwave"
    OVEN = "Oven"
    REFRIGERATOR = "Refrigerator"
    WARMING_DRAWER = "WarmingDrawer"
    WASHER = "Washer"
    WASHER_DRYER = "WasherDryer"
    WINE_COOLER = "WineCooler"


@dataclass
class HomeAppliance(DataClassJSONMixin):
    """Represent HomeAppliance."""

    ha_id: str = field(metadata=field_options(alias="haId"))
    name: str
    type: str
    brand: str
    vib: str
    e_number: str = field(metadata=field_options(alias="enumber"))
    connected: bool


@dataclass
class ArrayOfHomeAppliances(DataClassJSONMixin):
    """Object containing an array of home appliances."""

    homeappliances: list[HomeAppliance]



"""Provide fixtures for documentation tests."""

from sybil import Sybil
from sybil.evaluators.doctest import NUMBER
from sybil.parsers.myst import ClearNamespaceParser as MarkdownClearNamespaceParser
from sybil.parsers.myst import DocTestDirectiveParser as MarkdownDocTestParser
from sybil.parsers.myst import PythonCodeBlockParser as MarkdownPythonCodeBlockParser
from sybil.parsers.myst import SkipParser as MarkdownSkipParser
from sybil.parsers.rest import ClearNamespaceParser as ReSTClearNamespaceParser
from sybil.parsers.rest import DocTestParser as ReSTDocTestParser
from sybil.parsers.rest import PythonCodeBlockParser as ReSTPythonCodeBlockParser
from sybil.parsers.rest import SkipParser as ReSTSkipParser

markdown_examples = Sybil(
    parsers=[
        MarkdownDocTestParser(NUMBER),
        MarkdownPythonCodeBlockParser(doctest_optionflags=NUMBER),
        MarkdownSkipParser(),
        MarkdownClearNamespaceParser(),
    ],
    patterns=["*.md"],
)

rest_examples = Sybil(
    parsers=[
        ReSTDocTestParser(NUMBER),
        ReSTPythonCodeBlockParser(),
        ReSTSkipParser(),
        ReSTClearNamespaceParser(),
    ],
    patterns=["*.py", "*.rst"],
)

pytest_collect_file = (markdown_examples + rest_examples).pytest()
